beamtools.is_component_with_beam_spanner_attached
=================================================

.. autofunction:: abjad.tools.beamtools.is_component_with_beam_spanner_attached.is_component_with_beam_spanner_attached
   :noindex:
